pub struct EntryPoint {
pub cmd: Option<ZebradCmd>,
pub config: Option<PathBuf>,
pub verbose: bool,
filters: Vec<String>,
}Expand description
Toplevel entrypoint command.
Handles obtaining toplevel help as well as verbosity settings.
Fields
cmd: Option<ZebradCmd>Subcommand to execute.
The command option will delegate option parsing to the command type,
starting at the first free argument. Defaults to start.
config: Option<PathBuf>Path to the configuration file
verbose: boolIncrease verbosity setting
filters: Vec<String>Filter strings which override the config file and defaults
Implementations
Sourceimpl EntryPoint
impl EntryPoint
Sourcepub fn default_cmd_as_str() -> &'static str
pub fn default_cmd_as_str() -> &'static str
Returns a string that parses to the default subcommand
Sourcefn should_add_default_subcommand(&self) -> bool
fn should_add_default_subcommand(&self) -> bool
Checks if the provided arguments include a subcommand